@@ -1,7 +1,7 @@
 package Email::Simple::Markdown;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: simple email creation with auto text and html multipart body
-$Email::Simple::Markdown::VERSION = '0.7.1';
+$Email::Simple::Markdown::VERSION = '0.7.2';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ use Email::Abstract;
 use Email::MIME;
 use Email::Simple;
 
-use List::Util qw/ first pairmap /;
+use List::Util 1.29 qw/ first pairmap /;
 use Module::Runtime qw/ use_module /;
 
 use Moo;
@@ -179,7 +179,7 @@ Email::Simple::Markdown - simple email creation with auto text and html multipar
 
 =head1 VERSION
 
-version 0.7.1
+version 0.7.2
 
 =head1 SYNOPSIS
 
